/*
 * (c) Copyright IBM Corp 2001, 2006 
 */

package com.ibm.wsdl.tck;

import javax.wsdl.*;
import javax.wsdl.factory.*;
import javax.xml.parsers.*;
import junit.framework.*;
import org.w3c.dom.*;

/**
 * This class implements a series of tests used to check
 * javax.wsdl.Import implementations for compliance
 * with the JWSDL specification.
 *
 * @author Matthew J. Duftler (duftler@us.ibm.com)
 */
public class ImportTest extends TestCase
{
  private static final String TEST_CANDIDATE_PROPERTY_NAME =
    "javax.wsdl.factory.WSDLFactoryCandidate";
  private static final String NS_URI_WSDL =
    "http://schemas.xmlsoap.org/wsdl/";

  private WSDLFactory factory = null;
  private Definition definition = null;
  private Import _import = null;

  protected void setUp() throws WSDLException
  {
    // Determine name of JWSDL factory implementation to test.
    String testCandidateName =
      System.getProperty(TEST_CANDIDATE_PROPERTY_NAME);

    if (testCandidateName == null)
    {
      throw new IllegalArgumentException("System property '" +
                                         TEST_CANDIDATE_PROPERTY_NAME +
                                         "' must be specified to run " +
                                         "test suite.");
    }

    factory = WSDLFactory.newInstance(testCandidateName);

    Assert.assertNotNull("WSDLFactory should not be null.", factory);

    definition = factory.newDefinition();

    Assert.assertNotNull("Definition should not be null.", definition);

    _import = definition.createImport();

    Assert.assertNotNull("Import should not be null.", _import);
  }

  /**
   * Test Import.setDefinition(...) and Import.getDefinition().
   */
  public void testSetGetDefinition()
  {
    Definition definition2 = factory.newDefinition();

    Assert.assertNotNull("Definition should not be null.", definition2);

    _import.setDefinition(definition2);

    Definition definition3 = _import.getDefinition();

    Assert.assertTrue("Import.getDefinition() did not return " +
                      "the same Definition that was set using " +
                      "Import.setDefinition(...).",
                      definition2 == definition3);
  }

  /**
   * Test Import.setDocumentationElement(...) and
   * Import.getDocumentationElement().
   */
  public void testSetGetDocumentationElement()
    throws ParserConfigurationException
  {
    DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();

    factory.setNamespaceAware(true);
    factory.setValidating(false);

    DocumentBuilder builder = factory.newDocumentBuilder();
    Document doc = builder.newDocument();
    Element el = doc.createElementNS(NS_URI_WSDL,
                                     "wsdl:documentation");

    _import.setDocumentationElement(el);

    Element el2 = _import.getDocumentationElement();

    Assert.assertTrue("Import.getDocumentationElement() did not " +
                      "return the same Element that was set using " +
                      "Import.setDocumentationElement(...).",
                      el == el2);
  }

  /**
   * Test Import.setLocationURI(...) and Import.getLocationURI().
   */
  public void testSetGetLocationURI()
  {
    String locationURI = "abcdef";

    _import.setLocationURI(locationURI);

    String locationURI2 = _import.getLocationURI();

    Assert.assertTrue("Import.getLocationURI() did not return " +
                      "the same location URI that was set using " +
                      "Import.setLocationURI(...).",
                      locationURI.equals(locationURI2));
  }

  /**
   * Test Import.setNamespaceURI(...) and Import.getNamespaceURI().
   */
  public void testSetGetNamespaceURI()
  {
    String namespaceURI = "abcdef";

    _import.setNamespaceURI(namespaceURI);

    String namespaceURI2 = _import.getNamespaceURI();

    Assert.assertTrue("Import.getNamespaceURI() did not return " +
                      "the same namespace URI that was set using " +
                      "Import.setNamespaceURI(...).",
                      namespaceURI.equals(namespaceURI2));
  }
}